@@ -19,6 +19,7 @@ class Shard(Enum):
     XBOX_EU = 'xbox-eu'  # Europe
     XBOX_NA = 'xbox-na'  # North America
     XBOX_OC = 'xbox-oc'  # Oceania
+    XBOX_SA = 'xbox-sa'  # South America
     KAKAO = 'kakao'  # Kakao
     PSN = 'psn'
     STEAM = 'steam'
@@ -119,6 +120,7 @@ class Match(Domain):
         self.stats = self.attributes.get('stats')
         self.tags = self.attributes.get('tags')
         self.title_id = self.attributes.get('titleId')
+        self.season_state = self.attributes.get('seasonState')
 
 
 class Roster(Domain):
@@ -148,12 +150,9 @@ class Participant(Domain):
         self.headshot_kills = self.stats.get('headshotKills')
         self.heals = self.stats.get('heals')
         self.kill_place = self.stats.get('killPlace')
-        self.kill_points = self.stats.get('killPoints')
-        self.kill_points_delta = self.stats.get('killPointsDelta')
         self.kill_streaks = self.stats.get('killStreaks')
         self.kills = self.stats.get('kills')
         self.longest_kill = self.stats.get('longestKill')
-        self.most_damage = self.stats.get('mostDamage')
         self.name = self.stats.get('name')
         self.player_id = self.stats.get('playerId')
         self.revives = self.stats.get('revives')
@@ -166,8 +165,6 @@ class Participant(Domain):
         self.walk_distance = self.stats.get('walkDistance')
         self.weapons_acquired = self.stats.get('weaponsAcquired')
         self.win_place = self.stats.get('winPlace')
-        self.win_points = self.stats.get('winPoints')
-        self.win_points_delta = self.stats.get('winPointsDelta')
 
 
 class Asset(Domain):
@@ -189,6 +186,7 @@ class Player(Domain):
         self.shard_id = self.attributes.get('shardId')
         self.stats = self.attributes.get('stats')
         self.title_id = self.attributes.get('titleId')
+        self.rank = self.attributes.get('rank')
 
 
 class Tournament(Domain):
@@ -201,6 +199,7 @@ class Season(Domain):
         super().from_dict()
         self.is_current_season = self.attributes.get('isCurrentSeason')
         self.is_off_season = self.attributes.get('isOffSeason')
+        self.best_rank_point = self.attributes.get('bestRankPoint')
 
 
 class Playerseason(Domain):
@@ -222,38 +221,44 @@ class Stats(Domain):
 
     def from_dict(self):
         super().from_dict()
-        self.assists = self.attributes.get('assists')
-        self.boosts = self.attributes.get('boosts')
-        self.dbnos = self.attributes.get('dbnos')
-        self.daily_kills = self.attributes.get('dailyKills')
-        self.damage_dealt = self.attributes.get('damageDealt')
-        self.days = self.attributes.get('days')
-        self.daily_wins = self.attributes.get('dailyWins')
-        self.headshot_kills = self.attributes.get('headshotKills')
-        self.heals = self.attributes.get('heals')
-        self.kill_points = self.attributes.get('killPoints')
-        self.kills = self.attributes.get('kills')
-        self.longest_kill = self.attributes.get('longestKill')
-        self.longest_time_survived = self.attributes.get('longestTimeSurvived')
-        self.losses = self.attributes.get('losses')
-        self.max_kill_streaks = self.attributes.get('maxKillStreaks')
-        self.most_survival_time = self.attributes.get('mostSurvivalTime')
-        self.rank_points = self.attributes.get('rankPoints')
-        self.rank_points_title = self.attributes.get('rankPointsTitle')
-        self.revives = self.attributes.get('revives')
-        self.ride_distance = self.attributes.get('rideDistance')
-        self.road_kills = self.attributes.get('roadKills')
-        self.round_most_kills = self.attributes.get('roundMostKills')
-        self.rounds_played = self.attributes.get('roundsPlayed')
-        self.suicides = self.attributes.get('suicides')
-        self.swim_distance = self.attributes.get('swimDistance')
-        self.team_kills = self.attributes.get('teamKills')
-        self.time_survived = self.attributes.get('timeSurvived')
-        self.top10s = self.attributes.get('top10s')
-        self.vehicle_destroys = self.attributes.get('vehicleDestroys')
-        self.walk_distance = self.attributes.get('walkDistance')
-        self.weapons_acquired = self.attributes.get('weaponsAcquired')
-        self.weekly_kills = self.attributes.get('weeklyKills')
-        self.weekly_wins = self.attributes.get('weeklyWins')
-        self.win_points = self.attributes.get('winPoints')
-        self.wins = self.attributes.get('wins')
+        self.assists = self._data.get('assists')
+        self.boosts = self._data.get('boosts')
+        self.dbnos = self._data.get('dbnos')
+        self.daily_kills = self._data.get('dailyKills')
+        self.damage_dealt = self._data.get('damageDealt')
+        self.days = self._data.get('days')
+        self.daily_wins = self._data.get('dailyWins')
+        self.headshot_kills = self._data.get('headshotKills')
+        self.heals = self._data.get('heals')
+        self.kills = self._data.get('kills')
+        self.longest_kill = self._data.get('longestKill')
+        self.longest_time_survived = self._data.get('longestTimeSurvived')
+        self.losses = self._data.get('losses')
+        self.max_kill_streaks = self._data.get('maxKillStreaks')
+        self.most_survival_time = self._data.get('mostSurvivalTime')
+        self.rank_points = self._data.get('rankPoints')
+        self.rank_points_title = self._data.get('rankPointsTitle')
+        self.revives = self._data.get('revives')
+        self.ride_distance = self._data.get('rideDistance')
+        self.road_kills = self._data.get('roadKills')
+        self.round_most_kills = self._data.get('roundMostKills')
+        self.rounds_played = self._data.get('roundsPlayed')
+        self.suicides = self._data.get('suicides')
+        self.swim_distance = self._data.get('swimDistance')
+        self.team_kills = self._data.get('teamKills')
+        self.time_survived = self._data.get('timeSurvived')
+        self.top10s = self._data.get('top10s')
+        self.vehicle_destroys = self._data.get('vehicleDestroys')
+        self.walk_distance = self._data.get('walkDistance')
+        self.weapons_acquired = self._data.get('weaponsAcquired')
+        self.weekly_kills = self._data.get('weeklyKills')
+        self.weekly_wins = self._data.get('weeklyWins')
+        self.wins = self._data.get('wins')
+
+
+class Leaderboard(Domain):
+
+    def from_dict(self):
+        super().from_dict()
+        self.shard_id = self.attributes.get('shardId')
+        self.game_mode = self.attributes.get('gameMode')
